Crate codewhale_agent

Crate codewhale_agent 

Structs

ModelInfo
Metadata for a single model entry in the registry.
ModelRegistry
A registry of supported models and their aliases, used to resolve user-facing model names to concrete provider-specific model entries.
ModelResolution
The result of resolving a user-requested model name to a concrete model entry.

Enums

ModelFamily
High-level model family used for shared identity affordances across clients.

Functions

model_family
Classify a model identifier by its underlying model family.